@@ -14,8 +14,8 @@ class Computation(FairscapeBaseModel):
     associatedPublication: Optional[Union[str, AnyUrl]]
     additionalDocumentation: Optional[Union[str, AnyUrl]]
     command: Optional[Union[List[str], str]] 
-    usedSoftware: List[str]
+    usedSoftware: Optional[List[str]]
     calledBy: Optional[str]
-    usedDataset: Union[List[str], str]
-    generated: Union[str,List[str]]
+    usedDataset: Optional[Union[List[str], str]]
+    generated: Optional[Union[str,List[str]]]
      
