@@ -16,10 +16,10 @@ class Dataset(FairscapeBaseModel):
     additionalDocumentation: Optional[str]
     fileFormat: str
     dataSchema: Optional[Union[str, dict]]
-    generatedBy: List[str]
-    derivedFrom: List[str]
-    usedBy: List[str]
-    contentUrl: str
+    generatedBy: Optional[List[str]]
+    derivedFrom: Optional[List[str]]
+    usedBy: Optional[List[str]]
+    contentUrl: Optional[str]
 
     class Config:
         fields={
