@@ -15,8 +15,8 @@ class Software(FairscapeBaseModel):
     associatedPublication: Optional[str]
     additionalDocumentation: Optional[str]
     fileFormat: str
-    usedByComputation: List[str]
-    contentUrl: str
+    usedByComputation: Optional[List[str]]
+    contentUrl: Optional[str]
 
     class Config:
        fields={
